require 'spec_helper'


describe RipeDbClient do

  before(:each) do
    @client = RipeDbClient::Query.new('test', 'test')
  end

  describe "RipeDbClient::Query Object"  do

	  it "SHOULD create a new client" do
			c = RipeDbClient::Query.new
		  c.should_not be_nil
	  end

	  it "SHOULD default to the RIPE registry on creation" do
		  c = RipeDbClient::Query.new
		  c.source_registry?.should == "ripe"
	  end

	  it "SHOULD change the registry if you call the set_data_source function with a valid registry" do
		  c = RipeDbClient::Query.new
		  c.source_registry?.should == "ripe"
		  c.set_data_source("apnic")
		  c.source_registry?.should == "apnic"
	  end

	  it "SHOULD NOT change the registry if you call the set_data_source function with an invalid registry" do
		  c = RipeDbClient::Query.new
		  c.source_registry?.should == "ripe"
		  expect { c.set_data_source("arin") }.to raise_error(RipeDbClient::Unsupported, 'The only Supported registries are RIPE, AFRINIC, and APNIC')
		  c.source_registry?.should == "ripe"
	  end

	  it "SHOULD use http as its default mechanism" do
		  c = RipeDbClient::Query.new
		  c.secure_queries?.should be_false
    end

    it "SHOULD use https for queries if you set it up via set_secure_queries" do
      c = RipeDbClient::Query.new
      c.secure_queries?.should be_false
      c.set_secure_queries(true)
      c.secure_queries?.should be_true

    end

    it "SHOULD retrieve a list of the available query sources" do
      c = RipeDbClient::Query.new
      VCR.use_cassette('data_sources_object') do
        response = c.get_supported_data_sources
        response.should_not be_nil
      end
    end

    it "SHOULD raise an exception if the lookup_key is nil" do
      c = RipeDbClient::Query.new
      expect { c.lookup(nil,"something") }.to raise_error(RipeDbClient::BadParameter, 'lookup_key cannot be empty, or nil')
    end

    it "SHOULD raise an exception if the lookup_key is empty" do
      c = RipeDbClient::Query.new
      expect { c.lookup("","something") }.to raise_error(RipeDbClient::BadParameter, 'lookup_key cannot be empty, or nil')
    end

    it "SHOULD raise an exception if the lookup_value is nil" do
      c = RipeDbClient::Query.new
      expect { c.lookup("something", nil) }.to raise_error(RipeDbClient::BadParameter, 'lookup_value cannot be empty, or nil')
    end

    it "SHOULD raise an exception if the lookup_value is empty" do
      c = RipeDbClient::Query.new
      expect { c.lookup("something", "") }.to raise_error(RipeDbClient::BadParameter, 'lookup_value cannot be empty, or nil')
    end
	end
end

